@@ -711,28 +711,47 @@ class Customer(object):
                         'day_stop': int(day_stop)
                         }
                     )
+                # {day: [cdrs]}
             for day, infos in cdrs.items():
                 data = []
                 for interval in intervals:
+                    # {'Y-m-d':
+                    #   [
+                    #       {
+                    #           'time': 'H-M-S',
+                    #            'date': datetime,
+                    #       },
+                    #       {...}
+                    #   ]
+                    # }
                     for i in infos:
                         time = datetime.strptime(i['time'], '%H%M%S')
                         date_iso_weekday = i['date'].isoweekday()
-                        start_time = interval['start']
-                        stop_time = interval['stop']
+
+                        start_time = interval['start']  # ex: 09h00
+                        stop_time = interval['stop']  # ex: 18h59m59s
                         days_range = range(
                             interval['day_start'],
                             interval['day_stop']+1
-                            )
+                            )  # [1, 2, 3, 4, 5]
+
                         in_days = date_iso_weekday in days_range
+
+                        # ex: start at 08h < stop at 19h
                         if stop_time >= start_time:
                             in_times = (start_time <= time <= stop_time)
+                        # ex: start at 18h > stop at 09h
                         else:
                             in_times = (
                                 start_time <= time or time <= stop_time
                                 )
+
                         if (in_times and in_days):
                             data.append(i)
+
                 data = sorted(data, key=lambda x: x['source'])
+
+                # calculates octets in/out exclude 'national'
                 day_octets_in = sum(
                     [
                         i['octets_in'] for i in data
@@ -745,13 +764,19 @@ class Customer(object):
                         if i['source'] != 'national'
                         ]
                     )
+
                 day_total = day_octets_in + day_octets_out
+
                 data = groupby(data, key=lambda x: x['source'])
                 day_details = []
+
+                # source => ['internet', 'cache']
                 for source, element in data:
                     if source not in sources:
                         sources[source] = {'octets_in': 0, 'octets_out': 0}
+                    # sources = {'internet': {...}, 'cache': {...}}
                     element = list(element)
+
                     source_day_octets_in = sum(
                         [i['octets_in'] for i in element]
                         )
@@ -761,8 +786,17 @@ class Customer(object):
                     source_day_total = (
                         source_day_octets_in + source_day_octets_out
                         )
+
+                    # sources = {
+                    #   'internet': {
+                    #       'octets_in': 0 + 134
+                    #       'octets_out': 0 + 223
+                    #   }
+                    # }
                     sources[source]['octets_in'] += source_day_octets_in
                     sources[source]['octets_out'] += source_day_octets_out
+
+                    # [{...}, {...}]
                     day_details.append(
                         {
                             'source': source,
@@ -771,6 +805,7 @@ class Customer(object):
                             'total': source_day_total
                             }
                         )
+
                 info['total'] += day_total
                 info['octets_in'] += day_octets_in
                 info['octets_out'] += day_octets_out
@@ -783,6 +818,7 @@ class Customer(object):
                         'details': day_details
                         }
                     )
+
             policy_name_tab = policy_name.rsplit('_', 1)
             if policy_name_tab[1] == '2':
                 info['period'] = 'hc'
@@ -799,6 +835,7 @@ class Customer(object):
                 for source, bar in sources.items()
                 ]
             result.append(info)
+        LOGS.logger.info("[FUP CALCULATION] {}".format(result))
         return result
 
     def apply_product_policies(self, for_real=False):
